/* setup -- meta configuration tool calls other configuration tools.
 * Copyright (C) 1999-2002 Red Hat, Inc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include <libintl.h>
#include <locale.h>
#include <newt.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#define _(String) gettext(String)

int main(int argc, char **argv) {
   newtComponent lbox, run, quit, form,answer;
   newtGrid grid,grid2;
   int rc=0,command;
   char roottext[81];
   struct {
      char *name;
      char *path;
   } toollist[] = {
        {_(" Authentication configuration "),"/usr/sbin/authconfig"},
        {_(" Firewall configuration "),"/usr/sbin/lokkit"},
        {_(" Keyboard configuration "),"/usr/sbin/kbdconfig"},
        {_(" Mouse configuration "),"/usr/sbin/mouseconfig"},
        {_(" Network configuration "),"/usr/sbin/netconfig"},
        {_(" Printer configuration "),"/usr/sbin/printconf-tui"},
        {_(" System services "),"/usr/sbin/ntsysv"},
        {_(" Sound card configuration "),"/usr/sbin/sndconfig"},
        {_(" Timezone configuration "),"/usr/sbin/timeconfig"},
        {_(" X configuration "),"Xconfigurator"},
        {NULL, NULL},
   };

   setlocale(LC_ALL, "");
   bindtextdomain(GETTEXT_PACKAGE, "/usr/share/locale");
   textdomain(GETTEXT_PACKAGE);
   
   if (getuid()) {
      fprintf(stderr,
	      _("\nERROR - You must be root to run setup.\n"));
      exit(1);
   }
   lbox = newtListbox(2, 1, (sizeof(toollist) / (sizeof(toollist[0]))) - 1,
                      NEWT_FLAG_RETURNEXIT);
   for (rc = 0; toollist[rc].name != NULL; rc++) {
      if (access(toollist[rc].path, X_OK) == 0) {
	 newtListboxAddEntry(lbox, toollist[rc].name, (void*) rc);
      }
   }
   newtInit();
   newtCls();
   newtPushHelpLine(_("    <Tab>/<Alt-Tab> between elements  |"
		      "    Use <Enter> to edit a selection") );
   snprintf(roottext, sizeof(roottext),
	    _("Text Mode Setup Utility %-28s (c) 1999-2002 Red Hat, Inc."),
	      VERSION);
   newtDrawRootText(0, 0, roottext);
   form = newtForm(NULL, NULL, 0);
   grid = newtCreateGrid(1, 2);
   grid2 = newtButtonBar(_("Run Tool"), &run, _("Quit"), &quit, NULL);
   newtGridSetField(grid, 0, 0, NEWT_GRID_COMPONENT, lbox,
		    1, 0, 1, 0, NEWT_ANCHOR_TOP, 0);
   newtGridSetField(grid, 0, 1, NEWT_GRID_SUBGRID, grid2,
		    0, 1, 0, 0, NEWT_ANCHOR_TOP, 0);
   newtGridWrappedWindow(grid,_("Choose a Tool"));
   newtFormAddComponents(form, lbox, run, quit, NULL);
   while (rc!=-1) {
      answer = newtRunForm(form);
      if (answer != quit) {
	 command = (int)newtListboxGetCurrent(lbox);
	 rc = 0;
      } else {
	 rc = -1;
      }
      if (rc != -1) {
	 newtSuspend();
	 system(toollist[command].path);
	 newtResume();
      }
   }
   newtPopWindow();
   newtFormDestroy(form);
   newtFinished();
   return 0;
}
